@@ -5,6 +5,8 @@ use warnings;
 
 use base 'PocketIO::Sockets';
 
+use PocketIO::Room;
+
 sub send {
     my $self = shift;
 
@@ -24,6 +26,18 @@ sub emit {
     return $self;
 }
 
+
+sub to {
+    my $self = shift;
+    my ($room) = @_;
+
+    return PocketIO::Room->new(
+        room => $room,
+        conn => $self->{conn},
+        pool => $self->{pool}
+    );
+}
+
 1;
 __END__
 
@@ -49,4 +63,8 @@ Send message.
 
 Emit event.
 
+=head2 C<to>
+
+Only broadcast to a specific room.
+
 =cut
